==> humhub-1.11.0-beta.2.tar.gz: humhub-1.11.0-beta.2/protected/humhub/modules/space/messages/pl/base.php <==
<?php

return [
    '<b>This space is still empty!</b>' => '<b>Ta strefa jest jeszcze pusta!</b>',
    '<b>This space is still empty!</b><br>Start by posting something here...' => '<b>Ta strefa jest jeszcze pusta!</b><br />Aby zacząć coś tu napisz...',
    '<b>You are not member of this space and there is no public content, yet!</b>' => '<b>Nie jesteś członkiem tej strefy i nie ma tutaj jeszcze żadnych publicznych treści!</b>',
    '<strong>About</strong> the Space' => '<strong>Informacje</strong> o Strefie',
    '<strong>About</strong> your membership' => '<strong>Informacje</strong> o Twoim członkowstwie',
    '<strong>Confirm</strong> image deletion' => '<strong>Potwierdź</strong> usunięcie obrazu',
    '<strong>Invite</strong> members' => '<strong>Zaproś</strong> członków',
    '<strong>New</strong> member request' => '<strong>Nowe</strong> podanie o członkostwo',
    '<strong>New</strong> spaces' => '<strong>Nowe</strong> strefy',
    '<strong>Request</strong> space membership' => '<strong>Złóż podanie</strong> o członkostwo w strefie',
    '<strong>Space</strong> followers' => 'Obserwujący <strong>Strefę</strong>',
    '<strong>Space</strong> members' => '<strong>Członkowie</strong> strefy',
    '<strong>Space</strong> menu' => '<strong>Menu</strong> stref',
    '<strong>Space</strong> tags' => 'znaczniki <strong>Strefy</strong>',
    '<strong>Spaces</strong>' => '<strong>Strefy</strong>',
    'About' => 'O mnie',
    'Accept' => 'Akceptuj',
    'Accept Invite' => 'Zaakceptuj zaproszenie',
    'Add users without invitation' => 'Dodaj użytkowników bez zaproszenia',
    'Admin' => 'Admin',
    'Administrator:' => 'Administrator:',
    'Administrators' => 'Administratorzy',
    'Any' => 'Dowolne',
    'Application message' => 'Wiadomość o podanie',
    'Archived' => 'Zarchiwizowane',
    'As owner you cannot revoke your membership!' => 'Jako właściciel nie możesz odrzucić członkostwa!',
    'Blocked users' => 'Zablokowani użytkownicy',
    'By Name' => 'Po nazwie',
    'Cancel' => 'Anuluj',
    'Close' => 'Zamknij',
    'Color' => 'Kolor',
    'Could not request membership!' => 'Nie możesz poprosić o członkostwo!',
    'Created At' => 'Utworzona o',
    'Created By' => 'Utworzona przez',
    'Decline' => 'Odmów',
    'Decline Invite' => 'Odrzuć zaproszenie',
    'Default' => 'Domyślna',
    'Default content visibility' => 'Domyślna widoczność żawartośći',
    'Delete' => 'Usuń',
    'Description' => 'Opis',
    'Do you really want to delete your profile image?' => 'Na pewno chcesz usunąć obrazek profilowy?',
    'Do you really want to delete your title image?' => 'Na pewno chcesz usunąć obrazek tytułowy?',
    'Done' => 'Zrobione',
    'Email addresses' => 'Adres e-mail',
    'Everyone can enter' => 'Każdy może dołączyć',
    'Find Spaces by their description or by their tags' => 'Znajdź strefy po ich opisie lub znaczniku',
    'Follow' => 'Obserwuj',
    'Followers' => 'Obserwujący',
    'Following' => 'Obserwowani',
    'Guests' => 'Goście',
    'Hide Members sidebar in the stream page.' => 'Ukryj panel boczny Członkowie w strumieniu na stronie.',
    'Homepage' => 'Strona główna',
    'Homepage (Guests)' => 'Strona główna (Goście)',
    'Invite' => 'Zaproś',
    'Invite and request' => 'Zaproś i złóż podanie',
    'Invite by email' => 'Zaproś przez e-mail',
    'Invites' => 'Zaproszenia',
    'Join' => 'Dołącz',
    'Join Policy' => 'Polityka dołączania',
    'Last Visit' => 'Ostatnia wizyta',
    'Login' => 'Login',
    'Max. 100 characters.' => 'Maks. 100 znaków.',
    'Member' => 'Członek',
    'Member since' => 'Członek od',
    'Members' => 'Członkowie',
    'Moderator' => 'Moderator',
    'Moderator:' => 'Moderator:',
    'Moderators' => 'Moderatorzy',
    'My Space List' => 'Lista moich stref',
    'My space summary' => 'Podsumowanie moich stref',
    'Name' => 'Nazwa',
    'Neither..nor' => 'Żaden...',
    'New user by e-mail (comma separated)' => 'Nowi użytkownicy przez e-mail (oddzielone przecinkiem)',
    'New user?' => 'Nowy użytkownik?',
    'Newest first' => 'Nowsze najpierw',
    'No results found!' => 'Brak wyników!',
    'No spaces found.' => 'Nie znaleziono stref.',
    'Oldest first' => 'Starsze najpierw',
    'Only by invite' => 'Tylko przez zaproszenie',
    'Originator User ID' => 'ID oryginalnego Użytkownika',
    'Owner' => 'Właściciel',
    'Owner:' => 'Właściciel:',
    'Pending' => 'Trwające',
    'Pick users' => 'Wybierz użytkowników',
    'Please shortly introduce yourself, to become an approved member of this space.' => 'Proszę krótko się przedstaw, aby zostać zatwierdzonym członkiem tej strefy.',
    'Posts' => 'Wpisy',
    'Private' => 'Prywatna',
    'Private (Invisible)' => 'Prywatna (nie widoczna)',
    'Public' => 'Publiczna',
    'Public (Members & Guests)' => 'Publiczna (Członkowie i Goście)',
    'Public (Members only)' => 'Publiczna (Tylko członkowie)',
    'Public (Registered users only)' => 'Publiczna (Tylko zarejestrowani)',
    'Request Message' => 'Wiadomość żądania',
    'Role' => 'Funkcja',
    'Search...' => 'Szukaj...',
    'See all' => 'Zobacz całość',
    'Select all registered users' => 'Zaznacz wszystkich zarejestrowanych użytkowników',
    'Send' => 'Wyślij',
    'Settings' => 'Ustawienia',
    'Settings could not be saved!' => 'Ustawienia nie mogły zostać zapisane!',
    'Show all' => 'Pokaż wszystkich',
    'Shown on About Page.' => 'Pokazuj stronę Informacje.',
    'Sorry, you are not allowed to leave this space!' => 'Przepraszamy, nie masz uprawnień do opuszczenia strefy!',
    'Sorting' => 'Sortowanie',
    'Space' => 'Strefa',
    'Space Visibility' => 'Widoczność Strefy',
    'Space directory' => 'Katalog stref',
    'Space is invisible!' => 'Strefa jest niewidoczna !',
    'Spaces' => 'Strefy',
    'Status' => 'Status',
    'Stream' => 'Strumień',
    'Tags' => 'Tagi',
    'There is no pending invite!' => 'Nie ma oczekujących zaproszeń!',
    'This action is only available for workspace members!' => 'Działanie dostępne tylko dla członków grupy roboczej!',
    'This user is already a member of this space.' => 'Ten użytkownik jest już członkiem tej strefy.',
    'This user is not a member of this space.' => 'Ten użytkownik nie jest członkiem tej strefy.',
    'To invite users to this space, please type their names below to find and pick them.' => 'Aby zaprosić użytkowników do tej strefy, proszę podaj ich imiona poniżej aby ich znaleźć i wybrać.',
    'Try other keywords or remove filters.' => 'Wypróbuj inne słowa kluczowe lub usuń filtry.',
    'Updated At' => 'Zaktualizowana o',
    'Updated By' => 'Zaktualizowana przez',
    'Updated by' => 'Zaktualizowana przez',
    'User \'{username}\' is already a member of this space!' => 'Uzytkownik \'{username}\' jest już członkiem tej strefy!',
    'User invitations have been added to the queue' => 'Zaproszenia użytkowników zostały dodane do kolejki',
    'User memberships have been added to the queue' => 'Członkostwo użytkowników zostało dodane do kolejki',
    'User not found!' => 'Użytkownik nie znaleziony!',
    'Users' => 'Użytkownicy',
    'Users has been invited.' => 'Użytkownik został zaproszony,',
    'Visibility' => 'Widzialność',
    'Visible for all (members and guests)' => 'Widoczne dla wszystkich (użytkownicy i goście)',
    'Would you like to end your membership in Space {spaceName}?' => 'Czy chciałbyś zakończyć swoje członkostwo w Strefie {spaceName}?',
    'Would you like to unfollow Space {spaceName}?' => 'Czy chciałbyś przestać obserwować Strefę {spaceName}?',
    'Would you like to unfollow {userName}?' => 'Czy chciałbyś przestać obserwować {userName}?',
    'Would you like to withdraw your request to join Space {spaceName}?' => 'Czy chcesz wycofać prośbę o dołączenie do Strefy {spaceName}?',
    'You are not allowed to join this space!' => 'Nie masz zezwolenia na dołączenie do tej strefy!',
    'You can also invite external users, which are not registered now. Just add their e-mail addresses separated by comma.' => 'Możesz także zapraszać zewnętrznych użytkowników, którzy nie są obecnie zarejestrowani. Po prostu dodaj ich adresy e-mail oddzielone przecinkiem.',
    'You cannot create private visible spaces!' => 'Nie możesz tworzyć prywatnych i widzialnych stref!',
    'You cannot create public visible spaces!' => 'Nie możesz tworzyć publicznych i widzialnych stref!',
    'You need to login to view contents of this space!' => 'Aby oglądać treści w tej strefie, musisz się zalogować!',
    'Your request was successfully submitted to the space administrators.' => 'Twoje podanie z powodzeniem zostało dodane i przesłane administratorom strefy.',
    '{count} members' => '{count} członków',
    '{email} is not valid!' => '{email} nie jest prawidłowy!',
];

==> humhub-1.17.0-beta.2.tar.gz: humhub-1.17.0-beta.2/protected/humhub/modules/space/messages/pl/base.php <==
<?php

return [
    '<b>This space is still empty!</b>' => '<b>Ta strefa jest jeszcze pusta!</b>',
    '<b>This space is still empty!</b><br>Start by posting something here...' => '<b>Ta strefa jest jeszcze pusta!</b><br />Aby zacząć coś tu napisz...',
    '<b>You are not member of this space and there is no public content, yet!</b>' => '<b>Nie jesteś członkiem tej strefy i nie ma tutaj jeszcze żadnych publicznych treści!</b>',
    '<strong>About</strong> the Space' => '<strong>Informacje</strong> o Strefie',
    '<strong>About</strong> your membership' => '<strong>Informacje</strong> o Twoim członkowstwie',
    '<strong>Confirm</strong> image deletion' => '<strong>Potwierdź</strong> usunięcie obrazu',
    '<strong>Invite</strong> members' => '<strong>Zaproś</strong> członków',
    '<strong>New</strong> member request' => '<strong>Nowe</strong> podanie o członkostwo',
    '<strong>New</strong> spaces' => '<strong>Nowe</strong> strefy',
    '<strong>Request</strong> Membership' => '<strong>Złóż podanie</strong> o członkostwo w strefie',
    '<strong>Space</strong> followers' => 'Obserwujący <strong>Strefę</strong>',
    '<strong>Space</strong> members' => '<strong>Członkowie</strong> strefy',
    '<strong>Space</strong> menu' => '<strong>Menu</strong> stref',
    '<strong>Space</strong> tags' => 'znaczniki <strong>Strefy</strong>',
    '<strong>Spaces</strong>' => '<strong>Strefy</strong>',
    'About' => 'O mnie',
    'Accept' => 'Akceptuj',
    'Accept Invite' => 'Zaakceptuj zaproszenie',
    'Access to this Space is restricted. Please introduce yourself to become a member.' => 'Proszę krótko się przedstaw, aby zostać zatwierdzonym członkiem tej strefy.',
    'Add users without invitation' => 'Dodaj użytkowników bez zaproszenia',
    'Admin' => 'Admin',
    'Administrator:' => 'Administrator:',
    'Administrators' => 'Administratorzy',
    'Any' => 'Dowolne',
    'Archived' => 'Zarchiwizowane',
    'As owner you cannot revoke your membership!' => 'Jako właściciel nie możesz odrzucić członkostwa!',
    'Blocked users' => 'Zablokowani użytkownicy',
    'By Name' => 'Po nazwie',
    'Cancel' => 'Anuluj',
    'Close' => 'Zamknij',
    'Color' => 'Kolor',
    'Could not request membership!' => 'Nie możesz poprosić o członkostwo!',
    'Created At' => 'Utworzona o',
    'Created By' => 'Utworzona przez',
    'Decline' => 'Odmów',
    'Decline Invite' => 'Odrzuć zaproszenie',
    'Default' => 'Domyślna',
    'Default content visibility' => 'Domyślna widoczność żawartośći',
    'Delete' => 'Usuń',
    'Description' => 'Opis',
    'Do you really want to delete your profile image?' => 'Na pewno chcesz usunąć obrazek profilowy?',
    'Do you really want to delete your title image?' => 'Na pewno chcesz usunąć obrazek tytułowy?',
    'Done' => 'Zrobione',
    'Email addresses' => 'Adres e-mail',
    'Everyone can enter' => 'Każdy może dołączyć',
    'Find Spaces by their description or by their tags' => 'Znajdź strefy po ich opisie lub znaczniku',
    'Follow' => 'Obserwuj',
    'Followers' => 'Obserwujący',
    'Following' => 'Obserwowani',
    'Guests' => 'Goście',
    'Homepage' => 'Strona główna',
    'Invite' => 'Zaproś',
    'Invite and request' => 'Zaproś i złóż podanie',
    'Invite by email' => 'Zaproś przez e-mail',
    'Invite by link' => 'Zaproś poprzez link',
    'Invites' => 'Zaproszenia',
    'Join' => 'Dołącz',
    'Join Policy' => 'Polityka dołączania',
    'Last Visit' => 'Ostatnia wizyta',
    'Leave' => 'Opuść',
    'Login' => 'Login',
    'Max. 100 characters.' => 'Maks. 100 znaków.',
    'Member' => 'Członek',
    'Member since' => 'Członek od',
    'Members' => 'Członkowie',
    'Moderator' => 'Moderator',
    'Moderator:' => 'Moderator:',
    'Moderators' => 'Moderatorzy',
    'My Space List' => 'Lista moich stref',
    'My space summary' => 'Podsumowanie moich stref',
    'Name' => 'Nazwa',
    'Neither..nor' => 'Żaden...',
    'New user by e-mail (comma separated)' => 'Nowi użytkownicy przez e-mail (oddzielone przecinkiem)',
    'New user?' => 'Nowy użytkownik?',
    'Newest first' => 'Nowsze najpierw',
    'No results found!' => 'Brak wyników!',
    'No spaces found.' => 'Nie znaleziono stref.',
    'Oldest first' => 'Starsze najpierw',
    'Only by invite' => 'Tylko przez zaproszenie',
    'Originator User ID' => 'ID oryginalnego Użytkownika',
    'Owner' => 'Właściciel',
    'Owner:' => 'Właściciel:',
    'Pending' => 'Trwające',
    'Pick users' => 'Wybierz użytkowników',
    'Posts' => 'Wpisy',
    'Private' => 'Prywatna',
    'Private (Invisible)' => 'Prywatna (nie widoczna)',
    'Public' => 'Publiczna',
    'Public (Members & Guests)' => 'Publiczna (Członkowie i Goście)',
    'Public (Members only)' => 'Publiczna (Tylko członkowie)',
    'Public (Registered users only)' => 'Publiczna (Tylko zarejestrowani)',
    'Request Message' => 'Wiadomość żądania',
    'Role' => 'Funkcja',
    'Search...' => 'Szukaj...',
    'See all' => 'Zobacz całość',
    'Select all registered users' => 'Zaznacz wszystkich zarejestrowanych użytkowników',
    'Send' => 'Wyślij',
    'Settings' => 'Ustawienia',
    'Settings could not be saved!' => 'Ustawienia nie mogły zostać zapisane!',
    'Show all' => 'Pokaż wszystkich',
    'Shown on About Page.' => 'Pokazuj stronę Informacje.',
    'Sorry, you are not allowed to leave this space!' => 'Przepraszamy, nie masz uprawnień do opuszczenia strefy!',
    'Sorting' => 'Sortowanie',
    'Space' => 'Strefa',
    'Space Visibility' => 'Widoczność Strefy',
    'Space directory' => 'Katalog stref',
    'Space is invisible!' => 'Strefa jest niewidoczna !',
    'Spaces' => 'Strefy',
    'Status' => 'Status',
    'Stream' => 'Strumień',
    'Tags' => 'Tagi',
    'The secure link has been copied in your clipboard!' => 'Bezpieczny link został skopiowany do Twojego schowka!',
    'There is no pending invite!' => 'Nie ma oczekujących zaproszeń!',
    'This action is only available for workspace members!' => 'Działanie dostępne tylko dla członków grupy roboczej!',
    'This user is already a member of this space.' => 'Ten użytkownik jest już członkiem tej strefy.',
    'This user is not a member of this space.' => 'Ten użytkownik nie jest członkiem tej strefy.',
    'To invite users to this space, please type their names below to find and pick them.' => 'Aby zaprosić użytkowników do tej strefy, proszę podaj ich imiona poniżej aby ich znaleźć i wybrać.',
    'Try other keywords or remove filters.' => 'Wypróbuj inne słowa kluczowe lub usuń filtry.',
    'Updated At' => 'Zaktualizowana o',
    'Updated By' => 'Zaktualizowana przez',
    'Updated by' => 'Zaktualizowana przez',
    'User \'{username}\' is already a member of this space!' => 'Uzytkownik \'{username}\' jest już członkiem tej strefy!',
    'User invitations have been added to the queue' => 'Zaproszenia użytkowników zostały dodane do kolejki',
    'User memberships have been added to the queue' => 'Członkostwo użytkowników zostało dodane do kolejki',
    'User not found!' => 'Użytkownik nie znaleziony!',
    'Users' => 'Użytkownicy',
    'Users has been invited.' => 'Użytkownik został zaproszony,',
    'Visibility' => 'Widzialność',
    'Visible for all (members and guests)' => 'Widoczne dla wszystkich (użytkownicy i goście)',
    'Would you like to end your membership in Space {spaceName}?' => 'Czy chciałbyś zakończyć swoje członkostwo w Strefie {spaceName}?',
    'Would you like to unfollow Space {spaceName}?' => 'Czy chciałbyś przestać obserwować Strefę {spaceName}?',
    'Would you like to unfollow {userName}?' => 'Czy chciałbyś przestać obserwować {userName}?',
    'Would you like to withdraw your request to join Space {spaceName}?' => 'Czy chcesz wycofać prośbę o dołączenie do Strefy {spaceName}?',
    'You are not allowed to join this space!' => 'Nie masz zezwolenia na dołączenie do tej strefy!',
    'You cannot create private visible spaces!' => 'Nie możesz tworzyć prywatnych i widzialnych stref!',
    'You cannot create public visible spaces!' => 'Nie możesz tworzyć publicznych i widzialnych stref!',
    'You need to login to view contents of this space!' => 'Aby oglądać treści w tej strefie, musisz się zalogować!',
    'Your Message' => 'Wiadomość o podanie',
    'Your request was successfully submitted to the space administrators.' => 'Twoje podanie z powodzeniem zostało dodane i przesłane administratorom strefy.',
    '{count} members' => '{count} członków',
    '{email} is not valid!' => '{email} nie jest prawidłowy!',
    '<strong>Leave</strong> Space' => '',
    'Add as Default Space for new users' => '',
    'Advanced Spaces Search' => '',
    'Change visibility' => '',
    'Create new link' => '',
    'Default Stream Sort' => '',
    'Hide About Page' => '',
    'Hide Activity Sidebar Widget' => '',
    'Hide Followers' => '',
    'Hide Members' => '',
    'Homepage (Non-members)' => '',
    'I want to become a member because...' => '',
    'Incorrect name, try again.' => '',
    'Invite link' => '',
    'Name / Sort order' => '',
    'Please note that any links you have previously created will become invalid as soon as you create a new one. Would you like to proceed?' => '',
    'Send the link via email' => '',
    'Show as List' => '',
    'Space Name' => '',
    'Stream Sort' => '',
    'The default homepage for members of this Space' => '',
    'The default homepage for non-members and guests visiting this Space' => '',
    'Warning: If you change the visibility settings of a Space from public to private, all content within that Space, including posts, comments, attachments etc. will also be set to private. This means that non-members will no longer be able to see, access, or interact with any of the content within that Space.' => '',
    'You can also invite external users by email, which are not registered now. Just add their e-mail addresses separated by comma.' => '',
    'You can invite external users who are currently not registered via link. All you need to do is share this secure link with them.' => '',
];
